Index: src/objects.h |
diff --git a/src/objects.h b/src/objects.h |
index e52fac98ac4fac9c7b99bb2b3aa7032dbc4a7d61..e559733f5444717aa3e3217a7c42b84100a333ff 100644 |
--- a/src/objects.h |
+++ b/src/objects.h |
@@ -4713,7 +4713,6 @@ |
// Size is smi tagged when it is stored. |
static const int kSizeOffset = HeapObject::kHeaderSize; |
static const int kNextOffset = POINTER_SIZE_ALIGN(kSizeOffset + kPointerSize); |
- static const int kSize = kNextOffset + kPointerSize; |
private: |
DISALLOW_IMPLICIT_CONSTRUCTORS(FreeSpace); |
@@ -10479,12 +10478,12 @@ |
static const int kLengthOffset = JSObject::kHeaderSize; |
static const int kSize = kLengthOffset + kPointerSize; |
// 300 * KB is the Page::kMaxRegularHeapObjectSize defined in spaces.h which |
// we do not want to include in objects.h |
// Note that Page::kMaxRegularHeapObjectSize has to be in sync with |
// kInitialMaxFastElementArray which is checked in a DCHECK in heap.cc. |
static const int kInitialMaxFastElementArray = |
- (300 * KB - FixedArray::kHeaderSize - kSize - AllocationMemento::kSize) / |
+ (600 * KB - FixedArray::kHeaderSize - kSize - AllocationMemento::kSize) / |
kPointerSize; |
private: |
@@ -10479,12 +10478,12 @@ |
static const int kLengthOffset = JSObject::kHeaderSize; |
static const int kSize = kLengthOffset + kPointerSize; |
- // 300 * KB is the Page::kMaxRegularHeapObjectSize defined in spaces.h which |
+ // 600 * KB is the Page::kMaxRegularHeapObjectSize defined in spaces.h which |
// we do not want to include in objects.h |
// Note that Page::kMaxRegularHeapObjectSize has to be in sync with |